
#line 1 "lmscan.rl"
/*
 *  Copyright 2006-2007 Adrian Thurston <thurston@complang.org>
 */

/*  This file is part of Colm.
 *
 *  Colm is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 * 
 *  Colm is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Colm; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */

#include <iostream>
#include <fstream>
#include <string.h>

#include "colm.h"
#include "lmscan.h"
#include "lmparse.h"
#include "parsedata.h"
#include "avltree.h"
#include "vector.h"

//#define PRINT_TOKENS

using std::ifstream;
using std::istream;
using std::ostream;
using std::cout;
using std::cerr;
using std::endl;


#line 46 "lmscan.cpp"
static const int section_parse_start = 2;
static const int section_parse_first_final = 2;
static const int section_parse_error = 0;

static const int section_parse_en_main = 2;


#line 46 "lmscan.rl"


void Scanner::sectionParseInit()
{
	
#line 60 "lmscan.cpp"
	{
	cs = section_parse_start;
	}

#line 51 "lmscan.rl"
}

ostream &Scanner::scan_error()
{
	/* Maintain the error count. */
	gblErrorCount += 1;
	cerr << fileName << ":" << line << ":" << column << ": ";
	return cerr;
}

bool Scanner::recursiveInclude( const char *inclFileName )
{
	for ( IncludeStack::Iter si = includeStack; si.lte(); si++ ) {
		if ( strcmp( si->fileName, inclFileName ) == 0 )
			return true;
	}
	return false;	
}

void Scanner::updateCol()
{
	char *from = lastnl;
	if ( from == 0 )
		from = ts;
	//cerr << "adding " << te - from << " to column" << endl;
	column += te - from;
	lastnl = 0;
}

void Scanner::token( int type, char c )
{
	token( type, &c, &c + 1 );
}

void Scanner::token( int type )
{
	token( type, 0, 0 );
}

bool isAbsolutePath( const char *path )
{
	return path[0] == '/';
}

ifstream *Scanner::tryOpenInclude( char **pathChecks, long &found )
{
	char **check = pathChecks;
	ifstream *inFile = new ifstream;
	
	while ( *check != 0 ) {
		inFile->open( *check );
		if ( inFile->is_open() ) {
			found = check - pathChecks;
			return inFile;
		}
		check += 1;
	}

	found = -1;
	delete inFile;
	return 0;
}

char **Scanner::makeIncludePathChecks( const char *thisFileName, const char *fileName )
{
	char **checks = 0;
	long nextCheck = 0;
	char *data = strdup(fileName);
	long length = strlen(fileName);

	/* Absolute path? */
	if ( isAbsolutePath( data ) ) {
		checks = new char*[2];
		checks[nextCheck++] = data;
	}
	else {
		/* Search from the the location of the current file. */
		checks = new char *[2 + includePaths.length()];
		const char *lastSlash = strrchr( thisFileName, '/' );
		if ( lastSlash == 0 )
			checks[nextCheck++] = data;
		else {
			long givenPathLen = (lastSlash - thisFileName) + 1;
			long checklen = givenPathLen + length;
			char *check = new char[checklen+1];
			memcpy( check, thisFileName, givenPathLen );
			memcpy( check+givenPathLen, data, length );
			check[checklen] = 0;
			checks[nextCheck++] = check;
		}

		/* Search from the include paths given on the command line. */
		for ( ArgsVector::Iter incp = includePaths; incp.lte(); incp++ ) {
			long pathLen = strlen( *incp );
			long checkLen = pathLen + 1 + length;
			char *check = new char[checkLen+1];
			memcpy( check, *incp, pathLen );
			check[pathLen] = '/';
			memcpy( check+pathLen+1, data, length );
			check[checkLen] = 0;
			checks[nextCheck++] = check;
		}
	}

	checks[nextCheck] = 0;
	return checks;
}



#line 254 "lmscan.rl"


void Scanner::token( int type, char *start, char *end )
{
	char *tokdata = 0;
	int toklen = 0;
	int *p = &type;
	int *pe = &type + 1;
	int *eof = 0;

	if ( start != 0 ) {
		toklen = end-start;
		tokdata = new char[toklen+1];
		memcpy( tokdata, start, toklen );
		tokdata[toklen] = 0;
	}

	
#line 195 "lmscan.cpp"
	{
	if ( p == pe )
		goto _test_eof;
	switch ( cs )
	{
tr1:
#line 164 "lmscan.rl"
	{ word = lit = 0; word_len = lit_len = 0; }
#line 165 "lmscan.rl"
	{ lit = tokdata; lit_len = toklen; }
#line 172 "lmscan.rl"
	{
		String src( lit, lit_len );
		String fileName;
		bool unused;

		/* Need a location. */
		InputLoc here;
		here.fileName = fileName;
		here.line = line;
		here.col = column;

		prepareLitString( fileName, unused, src, here );
		char **checks = makeIncludePathChecks( this->fileName, fileName );

		/* Open the input file for reading. */
		long found = 0;
		ifstream *inFile = tryOpenInclude( checks, found );
		if ( inFile == 0 ) {
			scan_error() << "include: could not open " << 
					fileName << " for reading" << endl;
		}
		else {
			/* Only proceed with the include if it was found. */
			if ( recursiveInclude( checks[found] ) )
				scan_error() << "include: this is a recursive include operation" << endl;

			/* Check for a recursive include structure. Add the current file/section
			 * name then check if what we are including is already in the stack. */
			includeStack.append( IncludeStackItem( checks[found] ) );

			Scanner scanner( fileName, *inFile, output, parser, includeDepth+1 );
			scanner.scan();
			delete inFile;

			/* Remove the last element (len-1) */
			includeStack.remove( -1 );
		}
	}
	goto st2;
tr2:
#line 219 "lmscan.rl"
	{
//	cout << Parser_lelNames[type] << " ";
//	if ( start != 0 ) {
//		cout.write( start, end-start );
//	}
//	cout << endl;

		InputLoc loc;

		#ifdef PRINT_TOKENS
		cerr << "scanner:" << line << ":" << column << 
				": sending token to the parser " << Parser_lelNames[*p];
		cerr << " " << toklen;
		if ( tokdata != 0 )
			cerr << " " << tokdata;
		cerr << endl;
		#endif

		loc.fileName = fileName;
		loc.line = line;
		loc.col = column;

		if ( tokdata != 0 && tokdata[toklen-1] == '\n' )
			loc.line -= 1;

		parser->token( loc, type, tokdata, toklen );
	}
	goto st2;
st2:
	if ( ++p == pe )
		goto _test_eof2;
case 2:
#line 280 "lmscan.cpp"
	if ( (*p) == 203 )
		goto st1;
	goto tr2;
st1:
	if ( ++p == pe )
		goto _test_eof1;
case 1:
	if ( (*p) == 129 )
		goto tr1;
	goto tr0;
tr0:
#line 168 "lmscan.rl"
	{ scan_error() << "bad include statement" << endl; }
	goto st0;
#line 295 "lmscan.cpp"
st0:
cs = 0;
	goto _out;
	}
	_test_eof2: cs = 2; goto _test_eof; 
	_test_eof1: cs = 1; goto _test_eof; 

	_test_eof: {}
	if ( p == eof )
	{
	switch ( cs ) {
	case 1: 
#line 168 "lmscan.rl"
	{ scan_error() << "bad include statement" << endl; }
	break;
#line 311 "lmscan.cpp"
	}
	}

	_out: {}
	}

#line 274 "lmscan.rl"


	updateCol();
}

void Scanner::endSection( )
{
	/* Execute the eof actions for the section parser. */
	/* Probably use: token( -1 ); */
}


#line 539 "lmscan.rl"



#line 335 "lmscan.cpp"
static const int rlscan_start = 10;
static const int rlscan_first_final = 10;
static const int rlscan_error = -1;

static const int rlscan_en_or_literal = 184;
static const int rlscan_en_regular_type = 186;
static const int rlscan_en_literal_pattern = 203;
static const int rlscan_en_main = 10;


#line 542 "lmscan.rl"

void Scanner::scan()
{
	int bufsize = 8;
	char *buf = new char[bufsize];
	const char last_char = 0;
	int cs, act, have = 0;
	int top, stack[32];
	bool execute = true;

	sectionParseInit();
	
#line 359 "lmscan.cpp"
	{
	cs = rlscan_start;
	top = 0;
	ts = 0;
	te = 0;
	act = 0;
	}

#line 554 "lmscan.rl"

	while ( execute ) {
		char *p = buf + have;
		int space = bufsize - have;

		if ( space == 0 ) {
			/* We filled up the buffer trying to scan a token. Grow it. */
			bufsize = bufsize * 2;
			char *newbuf = new char[bufsize];

			/* Recompute p and space. */
			p = newbuf + have;
			space = bufsize - have;

			/* Patch up pointers possibly in use. */
			if ( ts != 0 )
				ts = newbuf + ( ts - buf );
			te = newbuf + ( te - buf );

			/* Copy the new buffer in. */
			memcpy( newbuf, buf, have );
			delete[] buf;
			buf = newbuf;
		}

		input.read( p, space );
		int len = input.gcount();

		/* If we see eof then append the EOF char. */
	 	if ( len == 0 ) {
			p[0] = last_char, len = 1;
			execute = false;
		}

		char *pe = p + len;
		char *eof = 0;
		
#line 406 "lmscan.cpp"
	{
	if ( p == pe )
		goto _test_eof;
	goto _resume;

_again:
	switch ( cs ) {
		case 10: goto st10;
		case 11: goto st11;
		case 12: goto st12;
		case 13: goto st13;
		case 0: goto st0;
		case 14: goto st14;
		case 15: goto st15;
		case 1: goto st1;
		case 2: goto st2;
		case 16: goto st16;
		case 17: goto st17;
		case 18: goto st18;
		case 19: goto st19;
		case 20: goto st20;
		case 21: goto st21;
		case 22: goto st22;
		case 23: goto st23;
		case 24: goto st24;
		case 25: goto st25;
		case 26: goto st26;
		case 27: goto st27;
		case 28: goto st28;
		case 29: goto st29;
		case 30: goto st30;
		case 31: goto st31;
		case 32: goto st32;
		case 33: goto st33;
		case 34: goto st34;
		case 35: goto st35;
		case 36: goto st36;
		case 37: goto st37;
		case 38: goto st38;
		case 39: goto st39;
		case 40: goto st40;
		case 41: goto st41;
		case 42: goto st42;
		case 43: goto st43;
		case 44: goto st44;
		case 45: goto st45;
		case 46: goto st46;
		case 47: goto st47;
		case 48: goto st48;
		case 49: goto st49;
		case 50: goto st50;
		case 51: goto st51;
		case 52: goto st52;
		case 53: goto st53;
		case 54: goto st54;
		case 55: goto st55;
		case 56: goto st56;
		case 57: goto st57;
		case 58: goto st58;
		case 59: goto st59;
		case 60: goto st60;
		case 61: goto st61;
		case 62: goto st62;
		case 63: goto st63;
		case 64: goto st64;
		case 65: goto st65;
		case 66: goto st66;
		case 67: goto st67;
		case 68: goto st68;
		case 69: goto st69;
		case 70: goto st70;
		case 71: goto st71;
		case 72: goto st72;
		case 73: goto st73;
		case 74: goto st74;
		case 75: goto st75;
		case 76: goto st76;
		case 77: goto st77;
		case 78: goto st78;
		case 79: goto st79;
		case 80: goto st80;
		case 81: goto st81;
		case 82: goto st82;
		case 83: goto st83;
		case 84: goto st84;
		case 85: goto st85;
		case 86: goto st86;
		case 87: goto st87;
		case 88: goto st88;
		case 89: goto st89;
		case 90: goto st90;
		case 91: goto st91;
		case 92: goto st92;
		case 93: goto st93;
		case 94: goto st94;
		case 95: goto st95;
		case 96: goto st96;
		case 97: goto st97;
		case 98: goto st98;
		case 99: goto st99;
		case 100: goto st100;
		case 101: goto st101;
		case 102: goto st102;
		case 103: goto st103;
		case 104: goto st104;
		case 105: goto st105;
		case 106: goto st106;
		case 107: goto st107;
		case 108: goto st108;
		case 109: goto st109;
		case 110: goto st110;
		case 111: goto st111;
		case 112: goto st112;
		case 113: goto st113;
		case 114: goto st114;
		case 115: goto st115;
		case 116: goto st116;
		case 117: goto st117;
		case 118: goto st118;
		case 119: goto st119;
		case 120: goto st120;
		case 121: goto st121;
		case 122: goto st122;
		case 123: goto st123;
		case 124: goto st124;
		case 125: goto st125;
		case 126: goto st126;
		case 127: goto st127;
		case 128: goto st128;
		case 129: goto st129;
		case 130: goto st130;
		case 131: goto st131;
		case 132: goto st132;
		case 133: goto st133;
		case 134: goto st134;
		case 135: goto st135;
		case 136: goto st136;
		case 137: goto st137;
		case 138: goto st138;
		case 139: goto st139;
		case 140: goto st140;
		case 141: goto st141;
		case 142: goto st142;
		case 143: goto st143;
		case 144: goto st144;
		case 145: goto st145;
		case 146: goto st146;
		case 147: goto st147;
		case 148: goto st148;
		case 149: goto st149;
		case 150: goto st150;
		case 151: goto st151;
		case 152: goto st152;
		case 153: goto st153;
		case 154: goto st154;
		case 155: goto st155;
		case 156: goto st156;
		case 157: goto st157;
		case 158: goto st158;
		case 159: goto st159;
		case 160: goto st160;
		case 161: goto st161;
		case 162: goto st162;
		case 163: goto st163;
		case 164: goto st164;
		case 165: goto st165;
		case 166: goto st166;
		case 167: goto st167;
		case 168: goto st168;
		case 169: goto st169;
		case 170: goto st170;
		case 171: goto st171;
		case 172: goto st172;
		case 173: goto st173;
		case 174: goto st174;
		case 175: goto st175;
		case 176: goto st176;
		case 177: goto st177;
		case 178: goto st178;
		case 179: goto st179;
		case 180: goto st180;
		case 181: goto st181;
		case 182: goto st182;
		case 183: goto st183;
		case 3: goto st3;
		case 184: goto st184;
		case 185: goto st185;
		case 186: goto st186;
		case 187: goto st187;
		case 188: goto st188;
		case 4: goto st4;
		case 189: goto st189;
		case 5: goto st5;
		case 190: goto st190;
		case 6: goto st6;
		case 191: goto st191;
		case 7: goto st7;
		case 8: goto st8;
		case 192: goto st192;
		case 193: goto st193;
		case 194: goto st194;
		case 195: goto st195;
		case 196: goto st196;
		case 9: goto st9;
		case 197: goto st197;
		case 198: goto st198;
		case 199: goto st199;
		case 200: goto st200;
		case 201: goto st201;
		case 202: goto st202;
		case 203: goto st203;
		case 204: goto st204;
	default: break;
	}

	if ( ++p == pe )
		goto _test_eof;
_resume:
	switch ( cs )
	{
tr0:
#line 537 "lmscan.rl"
	{{p = ((te))-1;}{ token( *ts ); }}
	goto st10;
tr2:
#line 291 "lmscan.rl"
	{ 
		lastnl = p; 
		column = 0;
		line++;
	}
#line 514 "lmscan.rl"
	{te = p+1;{ updateCol(); }}
	goto st10;
tr5:
#line 493 "lmscan.rl"
	{te = p+1;{
			token( TK_Literal, ts, te );
		}}
	goto st10;
tr8:
#line 291 "lmscan.rl"
	{ 
		lastnl = p; 
		column = 0;
		line++;
	}
#line 487 "lmscan.rl"
	{te = p+1;{ 
			token( '"' );
			token( TK_LitPat, ts+1, te );
			token( '"' );
		}}
	goto st10;
tr21:
#line 537 "lmscan.rl"
	{te = p+1;{ token( *ts ); }}
	goto st10;
tr22:
#line 535 "lmscan.rl"
	{te = p+1;}
	goto st10;
tr24:
#line 291 "lmscan.rl"
	{ 
		lastnl = p; 
		column = 0;
		line++;
	}
#line 532 "lmscan.rl"
	{te = p+1;{ updateCol(); }}
	goto st10;
tr26:
#line 497 "lmscan.rl"
	{te = p+1;{ 
			token( '"' );
			litBuf.clear(); 
			{stack[top++] = 10; goto st203;}
		}}
	goto st10;
tr28:
#line 527 "lmscan.rl"
	{te = p+1;{ token( *ts ); }}
	goto st10;
tr32:
#line 481 "lmscan.rl"
	{te = p+1;{ 
			token( '/' ); 
			if ( parser->enterRl )
				{stack[top++] = 10; goto st186;}
		}}
	goto st10;
tr39:
#line 502 "lmscan.rl"
	{te = p+1;{ 
			token( '[' ); 
			{stack[top++] = 10; goto st10;}
		}}
	goto st10;
tr40:
#line 507 "lmscan.rl"
	{te = p+1;{
			token( ']' );
			if ( top > 0 )
				{cs = stack[--top];goto _again;}
		}}
	goto st10;
tr60:
#line 531 "lmscan.rl"
	{te = p;p--;{ updateCol(); }}
	goto st10;
tr61:
#line 537 "lmscan.rl"
	{te = p;p--;{ token( *ts ); }}
	goto st10;
tr62:
#line 518 "lmscan.rl"
	{te = p+1;{ token( TK_NotEql ); }}
	goto st10;
tr63:
#line 523 "lmscan.rl"
	{te = p+1;{ token( TK_AmpAmp ); }}
	goto st10;
tr64:
#line 527 "lmscan.rl"
	{te = p;p--;{ token( *ts ); }}
	goto st10;
tr65:
#line 522 "lmscan.rl"
	{te = p+1;{ token( TK_RightArrow ); }}
	goto st10;
tr66:
#line 479 "lmscan.rl"
	{te = p;p--;{ token( TK_Number, ts, te ); }}
	goto st10;
tr67:
#line 519 "lmscan.rl"
	{te = p+1;{ token( TK_DoubleColon ); }}
	goto st10;
tr68:
#line 525 "lmscan.rl"
	{te = p+1;{ token( TK_LtLt ); }}
	goto st10;
tr69:
#line 520 "lmscan.rl"
	{te = p+1;{ token( TK_LessEql ); }}
	goto st10;
tr70:
#line 517 "lmscan.rl"
	{te = p+1;{ token( TK_DoubleEql ); }}
	goto st10;
tr71:
#line 516 "lmscan.rl"
	{te = p+1;{ token( TK_DoubleArrow ); }}
	goto st10;
tr72:
#line 521 "lmscan.rl"
	{te = p+1;{ token( TK_GrtrEql ); }}
	goto st10;
tr73:
#line 1 "NONE"
	{	switch( act ) {
	case 45:
	{{p = ((te))-1;} token( KW_Lex ); }
	break;
	case 46:
	{{p = ((te))-1;} token( KW_Commit ); }
	break;
	case 47:
	{{p = ((te))-1;} token( KW_Token ); }
	break;
	case 48:
	{{p = ((te))-1;} token( KW_Literal ); }
	break;
	case 49:
	{{p = ((te))-1;} token( KW_Rl ); }
	break;
	case 50:
	{{p = ((te))-1;} token( KW_Def ); }
	break;
	case 51:
	{{p = ((te))-1;} token( KW_Ignore ); }
	break;
	case 52:
	{{p = ((te))-1;} token( KW_Construct ); }
	break;
	case 54:
	{{p = ((te))-1;} token( KW_New ); }
	break;
	case 55:
	{{p = ((te))-1;} token( KW_If ); }
	break;
	case 56:
	{{p = ((te))-1;} token( KW_Reject ); }
	break;
	case 57:
	{{p = ((te))-1;} token( KW_While ); }
	break;
	case 58:
	{{p = ((te))-1;} token( KW_Else ); }
	break;
	case 59:
	{{p = ((te))-1;} token( KW_Elsif ); }
	break;
	case 60:
	{{p = ((te))-1;} token( KW_Match ); }
	break;
	case 61:
	{{p = ((te))-1;} token( KW_For ); }
	break;
	case 62:
	{{p = ((te))-1;} token( KW_Iter ); }
	break;
	case 63:
	{{p = ((te))-1;} token( KW_PrintStream ); }
	break;
	case 65:
	{{p = ((te))-1;} token( KW_PrintXMLAC ); }
	break;
	case 67:
	{{p = ((te))-1;} token( KW_Namespace ); }
	break;
	case 69:
	{{p = ((te))-1;} token( KW_Map ); }
	break;
	case 70:
	{{p = ((te))-1;} token( KW_List ); }
	break;
	case 71:
	{{p = ((te))-1;} token( KW_Vector ); }
	break;
	case 72:
	{{p = ((te))-1;} token( KW_Accum ); }
	break;
	case 73:
	{{p = ((te))-1;} token( KW_Accum ); }
	break;
	case 74:
	{{p = ((te))-1;} token( KW_Return ); }
	break;
	case 75:
	{{p = ((te))-1;} token( KW_Break ); }
	break;
	case 76:
	{{p = ((te))-1;} token( KW_Yield ); }
	break;
	case 77:
	{{p = ((te))-1;} token( KW_TypeId ); }
	break;
	case 78:
	{{p = ((te))-1;} token( KW_MakeToken ); }
	break;
	case 79:
	{{p = ((te))-1;} token( KW_MakeTree ); }
	break;
	case 80:
	{{p = ((te))-1;} token( KW_ReduceFirst ); }
	break;
	case 83:
	{{p = ((te))-1;} token( KW_Nil ); }
	break;
	case 84:
	{{p = ((te))-1;} token( KW_True ); }
	break;
	case 85:
	{{p = ((te))-1;} token( KW_False ); }
	break;
	case 87:
	{{p = ((te))-1;} token( KW_ParseStop ); }
	break;
	case 88:
	{{p = ((te))-1;} token( KW_Global ); }
	break;
	case 89:
	{{p = ((te))-1;} token( KW_Ptr ); }
	break;
	case 90:
	{{p = ((te))-1;} token( KW_Ref ); }
	break;
	case 91:
	{{p = ((te))-1;} token( KW_Deref ); }
	break;
	case 92:
	{{p = ((te))-1;} token( KW_Require ); }
	break;
	case 93:
	{{p = ((te))-1;} token( KW_Preeof ); }
	break;
	case 94:
	{{p = ((te))-1;} token( KW_Left ); }
	break;
	case 95:
	{{p = ((te))-1;} token( KW_Right ); }
	break;
	case 96:
	{{p = ((te))-1;} token( KW_Nonassoc ); }
	break;
	case 97:
	{{p = ((te))-1;} token( KW_Prec ); }
	break;
	case 98:
	{{p = ((te))-1;}token( KW_Include ); }
	break;
	case 99:
	{{p = ((te))-1;}token( KW_Context ); }
	break;
	case 100:
	{{p = ((te))-1;} token( TK_Word, ts, te ); }
	break;
	}
	}
	goto st10;
tr74:
#line 477 "lmscan.rl"
	{te = p;p--;{ token( TK_Word, ts, te ); }}
	goto st10;
tr91:
#line 428 "lmscan.rl"
	{te = p;p--;{ token( KW_Construct ); }}
	goto st10;
tr129:
#line 457 "lmscan.rl"
	{te = p;p--;{ token( KW_In ); }}
	goto st10;
tr190:
#line 461 "lmscan.rl"
	{te = p;p--;{ token( KW_Parse ); }}
	goto st10;
tr205:
#line 439 "lmscan.rl"
	{te = p;p--;{ token( KW_Print ); }}
	goto st10;
tr211:
#line 441 "lmscan.rl"
	{te = p;p--;{ token( KW_PrintXML ); }}
	goto st10;
tr270:
#line 524 "lmscan.rl"
	{te = p+1;{ token( TK_BarBar ); }}
	goto st10;
st10:
#line 1 "NONE"
	{ts = 0;}
	if ( ++p == pe )
		goto _test_eof10;
case 10:
#line 1 "NONE"
	{ts = p;}
#line 955 "lmscan.cpp"
	switch( (*p) ) {
		case 0: goto tr22;
		case 9: goto st11;
		case 10: goto tr24;
		case 13: goto st11;
		case 32: goto st11;
		case 33: goto st12;
		case 34: goto tr26;
		case 35: goto tr27;
		case 36: goto tr28;
		case 38: goto st14;
		case 39: goto tr30;
		case 45: goto st16;
		case 47: goto tr32;
		case 58: goto st18;
		case 60: goto st19;
		case 61: goto st20;
		case 62: goto st21;
		case 64: goto tr28;
		case 91: goto tr39;
		case 93: goto tr40;
		case 95: goto tr38;
		case 97: goto st23;
		case 98: goto st27;
		case 99: goto st31;
		case 100: goto st45;
		case 101: goto st49;
		case 102: goto st53;
		case 103: goto st58;
		case 105: goto st63;
		case 108: goto st75;
		case 109: goto st84;
		case 110: goto st97;
		case 112: goto st113;
		case 114: goto st136;
		case 116: goto st159;
		case 118: goto st169;
		case 119: goto st174;
		case 121: goto st178;
		case 124: goto st182;
		case 126: goto tr59;
	}
	if ( (*p) < 48 ) {
		if ( 40 <= (*p) && (*p) <= 43 )
			goto tr28;
	} else if ( (*p) > 57 ) {
		if ( (*p) > 90 ) {
			if ( 104 <= (*p) && (*p) <= 122 )
				goto tr38;
		} else if ( (*p) >= 65 )
			goto tr38;
	} else
		goto st17;
	goto tr21;
st11:
	if ( ++p == pe )
		goto _test_eof11;
case 11:
	switch( (*p) ) {
		case 9: goto st11;
		case 13: goto st11;
		case 32: goto st11;
	}
	goto tr60;
st12:
	if ( ++p == pe )
		goto _test_eof12;
case 12:
	if ( (*p) == 61 )
		goto tr62;
	goto tr61;
tr27:
#line 1 "NONE"
	{te = p+1;}
	goto st13;
st13:
	if ( ++p == pe )
		goto _test_eof13;
case 13:
#line 1035 "lmscan.cpp"
	if ( (*p) == 10 )
		goto tr2;
	goto st0;
st0:
	if ( ++p == pe )
		goto _test_eof0;
case 0:
	if ( (*p) == 10 )
		goto tr2;
	goto st0;
st14:
	if ( ++p == pe )
		goto _test_eof14;
case 14:
	if ( (*p) == 38 )
		goto tr63;
	goto tr61;
tr30:
#line 1 "NONE"
	{te = p+1;}
	goto st15;
st15:
	if ( ++p == pe )
		goto _test_eof15;
case 15:
#line 1061 "lmscan.cpp"
	switch( (*p) ) {
		case 10: goto tr4;
		case 39: goto tr5;
		case 92: goto st2;
	}
	goto st1;
tr4:
#line 291 "lmscan.rl"
	{ 
		lastnl = p; 
		column = 0;
		line++;
	}
	goto st1;
st1:
	if ( ++p == pe )
		goto _test_eof1;
case 1:
#line 1080 "lmscan.cpp"
	switch( (*p) ) {
		case 10: goto tr4;
		case 39: goto tr5;
		case 92: goto st2;
	}
	goto st1;
st2:
	if ( ++p == pe )
		goto _test_eof2;
case 2:
	if ( (*p) == 10 )
		goto tr4;
	goto st1;
st16:
	if ( ++p == pe )
		goto _test_eof16;
case 16:
	if ( (*p) == 62 )
		goto tr65;
	goto tr64;
st17:
	if ( ++p == pe )
		goto _test_eof17;
case 17:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto st17;
	goto tr66;
st18:
	if ( ++p == pe )
		goto _test_eof18;
case 18:
	if ( (*p) == 58 )
		goto tr67;
	goto tr61;
st19:
	if ( ++p == pe )
		goto _test_eof19;
case 19:
	switch( (*p) ) {
		case 60: goto tr68;
		case 61: goto tr69;
	}
	goto tr61;
st20:
	if ( ++p == pe )
		goto _test_eof20;
case 20:
	switch( (*p) ) {
		case 61: goto tr70;
		case 62: goto tr71;
	}
	goto tr61;
st21:
	if ( ++p == pe )
		goto _test_eof21;
case 21:
	if ( (*p) == 61 )
		goto tr72;
	goto tr61;
tr38:
#line 1 "NONE"
	{te = p+1;}
#line 477 "lmscan.rl"
	{act = 100;}
	goto st22;
tr78:
#line 1 "NONE"
	{te = p+1;}
#line 447 "lmscan.rl"
	{act = 72;}
	goto st22;
tr82:
#line 1 "NONE"
	{te = p+1;}
#line 450 "lmscan.rl"
	{act = 75;}
	goto st22;
tr88:
#line 1 "NONE"
	{te = p+1;}
#line 421 "lmscan.rl"
	{act = 46;}
	goto st22;
tr96:
#line 1 "NONE"
	{te = p+1;}
#line 427 "lmscan.rl"
	{act = 52;}
	goto st22;
tr99:
#line 1 "NONE"
	{te = p+1;}
#line 474 "lmscan.rl"
	{act = 99;}
	goto st22;
tr101:
#line 1 "NONE"
	{te = p+1;}
#line 425 "lmscan.rl"
	{act = 50;}
	goto st22;
tr104:
#line 1 "NONE"
	{te = p+1;}
#line 466 "lmscan.rl"
	{act = 91;}
	goto st22;
tr107:
#line 1 "NONE"
	{te = p+1;}
#line 433 "lmscan.rl"
	{act = 58;}
	goto st22;
tr109:
#line 1 "NONE"
	{te = p+1;}
#line 434 "lmscan.rl"
	{act = 59;}
	goto st22;
tr114:
#line 1 "NONE"
	{te = p+1;}
#line 460 "lmscan.rl"
	{act = 85;}
	goto st22;
tr115:
#line 1 "NONE"
	{te = p+1;}
#line 436 "lmscan.rl"
	{act = 61;}
	goto st22;
tr120:
#line 1 "NONE"
	{te = p+1;}
#line 463 "lmscan.rl"
	{act = 88;}
	goto st22;
tr121:
#line 1 "NONE"
	{te = p+1;}
#line 430 "lmscan.rl"
	{act = 55;}
	goto st22;
tr128:
#line 1 "NONE"
	{te = p+1;}
#line 426 "lmscan.rl"
	{act = 51;}
	goto st22;
tr134:
#line 1 "NONE"
	{te = p+1;}
#line 473 "lmscan.rl"
	{act = 98;}
	goto st22;
tr136:
#line 1 "NONE"
	{te = p+1;}
#line 437 "lmscan.rl"
	{act = 62;}
	goto st22;
tr140:
#line 1 "NONE"
	{te = p+1;}
#line 420 "lmscan.rl"
	{act = 45;}
	goto st22;
tr141:
#line 1 "NONE"
	{te = p+1;}
#line 469 "lmscan.rl"
	{act = 94;}
	goto st22;
tr144:
#line 1 "NONE"
	{te = p+1;}
#line 445 "lmscan.rl"
	{act = 70;}
	goto st22;
tr148:
#line 1 "NONE"
	{te = p+1;}
#line 423 "lmscan.rl"
	{act = 48;}
	goto st22;
tr151:
#line 1 "NONE"
	{te = p+1;}
#line 444 "lmscan.rl"
	{act = 69;}
	goto st22;
tr160:
#line 1 "NONE"
	{te = p+1;}
#line 453 "lmscan.rl"
	{act = 78;}
	goto st22;
tr162:
#line 1 "NONE"
	{te = p+1;}
#line 454 "lmscan.rl"
	{act = 79;}
	goto st22;
tr164:
#line 1 "NONE"
	{te = p+1;}
#line 435 "lmscan.rl"
	{act = 60;}
	goto st22;
tr175:
#line 1 "NONE"
	{te = p+1;}
#line 442 "lmscan.rl"
	{act = 67;}
	goto st22;
tr176:
#line 1 "NONE"
	{te = p+1;}
#line 429 "lmscan.rl"
	{act = 54;}
	goto st22;
tr177:
#line 1 "NONE"
	{te = p+1;}
#line 458 "lmscan.rl"
	{act = 83;}
	goto st22;
tr183:
#line 1 "NONE"
	{te = p+1;}
#line 471 "lmscan.rl"
	{act = 96;}
	goto st22;
tr192:
#line 1 "NONE"
	{te = p+1;}
#line 448 "lmscan.rl"
	{act = 73;}
	goto st22;
tr196:
#line 1 "NONE"
	{te = p+1;}
#line 462 "lmscan.rl"
	{act = 87;}
	goto st22;
tr199:
#line 1 "NONE"
	{te = p+1;}
#line 472 "lmscan.rl"
	{act = 97;}
	goto st22;
tr202:
#line 1 "NONE"
	{te = p+1;}
#line 468 "lmscan.rl"
	{act = 93;}
	goto st22;
tr207:
#line 1 "NONE"
	{te = p+1;}
#line 438 "lmscan.rl"
	{act = 63;}
	goto st22;
tr214:
#line 1 "NONE"
	{te = p+1;}
#line 440 "lmscan.rl"
	{act = 65;}
	goto st22;
tr215:
#line 1 "NONE"
	{te = p+1;}
#line 464 "lmscan.rl"
	{act = 89;}
	goto st22;
tr218:
#line 1 "NONE"
	{te = p+1;}
#line 424 "lmscan.rl"
	{act = 49;}
	goto st22;
tr220:
#line 1 "NONE"
	{te = p+1;}
#line 465 "lmscan.rl"
	{act = 90;}
	goto st22;
tr231:
#line 1 "NONE"
	{te = p+1;}
#line 455 "lmscan.rl"
	{act = 80;}
	goto st22;
tr234:
#line 1 "NONE"
	{te = p+1;}
#line 431 "lmscan.rl"
	{act = 56;}
	goto st22;
tr238:
#line 1 "NONE"
	{te = p+1;}
#line 467 "lmscan.rl"
	{act = 92;}
	goto st22;
tr241:
#line 1 "NONE"
	{te = p+1;}
#line 449 "lmscan.rl"
	{act = 74;}
	goto st22;
tr244:
#line 1 "NONE"
	{te = p+1;}
#line 470 "lmscan.rl"
	{act = 95;}
	goto st22;
tr250:
#line 1 "NONE"
	{te = p+1;}
#line 422 "lmscan.rl"
	{act = 47;}
	goto st22;
tr252:
#line 1 "NONE"
	{te = p+1;}
#line 459 "lmscan.rl"
	{act = 84;}
	goto st22;
tr256:
#line 1 "NONE"
	{te = p+1;}
#line 452 "lmscan.rl"
	{act = 77;}
	goto st22;
tr261:
#line 1 "NONE"
	{te = p+1;}
#line 446 "lmscan.rl"
	{act = 71;}
	goto st22;
tr265:
#line 1 "NONE"
	{te = p+1;}
#line 432 "lmscan.rl"
	{act = 57;}
	goto st22;
tr269:
#line 1 "NONE"
	{te = p+1;}
#line 451 "lmscan.rl"
	{act = 76;}
	goto st22;
st22:
	if ( ++p == pe )
		goto _test_eof22;
case 22:
#line 1438 "lmscan.cpp"
	if ( (*p) == 95 )
		goto tr38;
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr73;
st23:
	if ( ++p == pe )
		goto _test_eof23;
case 23:
	switch( (*p) ) {
		case 95: goto tr38;
		case 99: goto st24;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st24:
	if ( ++p == pe )
		goto _test_eof24;
case 24:
	switch( (*p) ) {
		case 95: goto tr38;
		case 99: goto st25;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st25:
	if ( ++p == pe )
		goto _test_eof25;
case 25:
	switch( (*p) ) {
		case 95: goto tr38;
		case 117: goto st26;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st26:
	if ( ++p == pe )
		goto _test_eof26;
case 26:
	switch( (*p) ) {
		case 95: goto tr38;
		case 109: goto tr78;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st27:
	if ( ++p == pe )
		goto _test_eof27;
case 27:
	switch( (*p) ) {
		case 95: goto tr38;
		case 114: goto st28;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st28:
	if ( ++p == pe )
		goto _test_eof28;
case 28:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st29;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st29:
	if ( ++p == pe )
		goto _test_eof29;
case 29:
	switch( (*p) ) {
		case 95: goto tr38;
		case 97: goto st30;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 98 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st30:
	if ( ++p == pe )
		goto _test_eof30;
case 30:
	switch( (*p) ) {
		case 95: goto tr38;
		case 107: goto tr82;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st31:
	if ( ++p == pe )
		goto _test_eof31;
case 31:
	switch( (*p) ) {
		case 95: goto tr38;
		case 111: goto st32;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st32:
	if ( ++p == pe )
		goto _test_eof32;
case 32:
	switch( (*p) ) {
		case 95: goto tr38;
		case 109: goto st33;
		case 110: goto st36;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st33:
	if ( ++p == pe )
		goto _test_eof33;
case 33:
	switch( (*p) ) {
		case 95: goto tr38;
		case 109: goto st34;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st34:
	if ( ++p == pe )
		goto _test_eof34;
case 34:
	switch( (*p) ) {
		case 95: goto tr38;
		case 105: goto st35;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st35:
	if ( ++p == pe )
		goto _test_eof35;
case 35:
	switch( (*p) ) {
		case 95: goto tr38;
		case 116: goto tr88;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st36:
	if ( ++p == pe )
		goto _test_eof36;
case 36:
	switch( (*p) ) {
		case 95: goto tr38;
		case 115: goto st37;
		case 116: goto st42;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st37:
	if ( ++p == pe )
		goto _test_eof37;
case 37:
	switch( (*p) ) {
		case 95: goto tr38;
		case 116: goto st38;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr91;
st38:
	if ( ++p == pe )
		goto _test_eof38;
case 38:
	switch( (*p) ) {
		case 95: goto tr38;
		case 114: goto st39;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st39:
	if ( ++p == pe )
		goto _test_eof39;
case 39:
	switch( (*p) ) {
		case 95: goto tr38;
		case 117: goto st40;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st40:
	if ( ++p == pe )
		goto _test_eof40;
case 40:
	switch( (*p) ) {
		case 95: goto tr38;
		case 99: goto st41;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st41:
	if ( ++p == pe )
		goto _test_eof41;
case 41:
	switch( (*p) ) {
		case 95: goto tr38;
		case 116: goto tr96;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st42:
	if ( ++p == pe )
		goto _test_eof42;
case 42:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st43;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st43:
	if ( ++p == pe )
		goto _test_eof43;
case 43:
	switch( (*p) ) {
		case 95: goto tr38;
		case 120: goto st44;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st44:
	if ( ++p == pe )
		goto _test_eof44;
case 44:
	switch( (*p) ) {
		case 95: goto tr38;
		case 116: goto tr99;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st45:
	if ( ++p == pe )
		goto _test_eof45;
case 45:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st46;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st46:
	if ( ++p == pe )
		goto _test_eof46;
case 46:
	switch( (*p) ) {
		case 95: goto tr38;
		case 102: goto tr101;
		case 114: goto st47;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st47:
	if ( ++p == pe )
		goto _test_eof47;
case 47:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st48;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st48:
	if ( ++p == pe )
		goto _test_eof48;
case 48:
	switch( (*p) ) {
		case 95: goto tr38;
		case 102: goto tr104;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st49:
	if ( ++p == pe )
		goto _test_eof49;
case 49:
	switch( (*p) ) {
		case 95: goto tr38;
		case 108: goto st50;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st50:
	if ( ++p == pe )
		goto _test_eof50;
case 50:
	switch( (*p) ) {
		case 95: goto tr38;
		case 115: goto st51;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st51:
	if ( ++p == pe )
		goto _test_eof51;
case 51:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto tr107;
		case 105: goto st52;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st52:
	if ( ++p == pe )
		goto _test_eof52;
case 52:
	switch( (*p) ) {
		case 95: goto tr38;
		case 102: goto tr109;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st53:
	if ( ++p == pe )
		goto _test_eof53;
case 53:
	switch( (*p) ) {
		case 95: goto tr38;
		case 97: goto st54;
		case 111: goto st57;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 98 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st54:
	if ( ++p == pe )
		goto _test_eof54;
case 54:
	switch( (*p) ) {
		case 95: goto tr38;
		case 108: goto st55;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st55:
	if ( ++p == pe )
		goto _test_eof55;
case 55:
	switch( (*p) ) {
		case 95: goto tr38;
		case 115: goto st56;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st56:
	if ( ++p == pe )
		goto _test_eof56;
case 56:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto tr114;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st57:
	if ( ++p == pe )
		goto _test_eof57;
case 57:
	switch( (*p) ) {
		case 95: goto tr38;
		case 114: goto tr115;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st58:
	if ( ++p == pe )
		goto _test_eof58;
case 58:
	switch( (*p) ) {
		case 95: goto tr38;
		case 108: goto st59;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st59:
	if ( ++p == pe )
		goto _test_eof59;
case 59:
	switch( (*p) ) {
		case 95: goto tr38;
		case 111: goto st60;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st60:
	if ( ++p == pe )
		goto _test_eof60;
case 60:
	switch( (*p) ) {
		case 95: goto tr38;
		case 98: goto st61;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st61:
	if ( ++p == pe )
		goto _test_eof61;
case 61:
	switch( (*p) ) {
		case 95: goto tr38;
		case 97: goto st62;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 98 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st62:
	if ( ++p == pe )
		goto _test_eof62;
case 62:
	switch( (*p) ) {
		case 95: goto tr38;
		case 108: goto tr120;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st63:
	if ( ++p == pe )
		goto _test_eof63;
case 63:
	switch( (*p) ) {
		case 95: goto tr38;
		case 102: goto tr121;
		case 103: goto st64;
		case 110: goto st68;
		case 116: goto st73;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st64:
	if ( ++p == pe )
		goto _test_eof64;
case 64:
	switch( (*p) ) {
		case 95: goto tr38;
		case 110: goto st65;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st65:
	if ( ++p == pe )
		goto _test_eof65;
case 65:
	switch( (*p) ) {
		case 95: goto tr38;
		case 111: goto st66;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st66:
	if ( ++p == pe )
		goto _test_eof66;
case 66:
	switch( (*p) ) {
		case 95: goto tr38;
		case 114: goto st67;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st67:
	if ( ++p == pe )
		goto _test_eof67;
case 67:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto tr128;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st68:
	if ( ++p == pe )
		goto _test_eof68;
case 68:
	switch( (*p) ) {
		case 95: goto tr38;
		case 99: goto st69;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr129;
st69:
	if ( ++p == pe )
		goto _test_eof69;
case 69:
	switch( (*p) ) {
		case 95: goto tr38;
		case 108: goto st70;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st70:
	if ( ++p == pe )
		goto _test_eof70;
case 70:
	switch( (*p) ) {
		case 95: goto tr38;
		case 117: goto st71;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st71:
	if ( ++p == pe )
		goto _test_eof71;
case 71:
	switch( (*p) ) {
		case 95: goto tr38;
		case 100: goto st72;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st72:
	if ( ++p == pe )
		goto _test_eof72;
case 72:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto tr134;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st73:
	if ( ++p == pe )
		goto _test_eof73;
case 73:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st74;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st74:
	if ( ++p == pe )
		goto _test_eof74;
case 74:
	switch( (*p) ) {
		case 95: goto tr38;
		case 114: goto tr136;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st75:
	if ( ++p == pe )
		goto _test_eof75;
case 75:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st76;
		case 105: goto st78;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st76:
	if ( ++p == pe )
		goto _test_eof76;
case 76:
	switch( (*p) ) {
		case 95: goto tr38;
		case 102: goto st77;
		case 120: goto tr140;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st77:
	if ( ++p == pe )
		goto _test_eof77;
case 77:
	switch( (*p) ) {
		case 95: goto tr38;
		case 116: goto tr141;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st78:
	if ( ++p == pe )
		goto _test_eof78;
case 78:
	switch( (*p) ) {
		case 95: goto tr38;
		case 115: goto st79;
		case 116: goto st80;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st79:
	if ( ++p == pe )
		goto _test_eof79;
case 79:
	switch( (*p) ) {
		case 95: goto tr38;
		case 116: goto tr144;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st80:
	if ( ++p == pe )
		goto _test_eof80;
case 80:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st81;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st81:
	if ( ++p == pe )
		goto _test_eof81;
case 81:
	switch( (*p) ) {
		case 95: goto tr38;
		case 114: goto st82;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st82:
	if ( ++p == pe )
		goto _test_eof82;
case 82:
	switch( (*p) ) {
		case 95: goto tr38;
		case 97: goto st83;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 98 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st83:
	if ( ++p == pe )
		goto _test_eof83;
case 83:
	switch( (*p) ) {
		case 95: goto tr38;
		case 108: goto tr148;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st84:
	if ( ++p == pe )
		goto _test_eof84;
case 84:
	switch( (*p) ) {
		case 95: goto tr38;
		case 97: goto st85;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 98 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st85:
	if ( ++p == pe )
		goto _test_eof85;
case 85:
	switch( (*p) ) {
		case 95: goto tr38;
		case 107: goto st86;
		case 112: goto tr151;
		case 116: goto st95;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st86:
	if ( ++p == pe )
		goto _test_eof86;
case 86:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st87;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st87:
	if ( ++p == pe )
		goto _test_eof87;
case 87:
	if ( (*p) == 95 )
		goto st88;
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st88:
	if ( ++p == pe )
		goto _test_eof88;
case 88:
	switch( (*p) ) {
		case 95: goto tr38;
		case 116: goto st89;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st89:
	if ( ++p == pe )
		goto _test_eof89;
case 89:
	switch( (*p) ) {
		case 95: goto tr38;
		case 111: goto st90;
		case 114: goto st93;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st90:
	if ( ++p == pe )
		goto _test_eof90;
case 90:
	switch( (*p) ) {
		case 95: goto tr38;
		case 107: goto st91;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st91:
	if ( ++p == pe )
		goto _test_eof91;
case 91:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st92;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st92:
	if ( ++p == pe )
		goto _test_eof92;
case 92:
	switch( (*p) ) {
		case 95: goto tr38;
		case 110: goto tr160;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st93:
	if ( ++p == pe )
		goto _test_eof93;
case 93:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st94;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st94:
	if ( ++p == pe )
		goto _test_eof94;
case 94:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto tr162;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st95:
	if ( ++p == pe )
		goto _test_eof95;
case 95:
	switch( (*p) ) {
		case 95: goto tr38;
		case 99: goto st96;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st96:
	if ( ++p == pe )
		goto _test_eof96;
case 96:
	switch( (*p) ) {
		case 95: goto tr38;
		case 104: goto tr164;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st97:
	if ( ++p == pe )
		goto _test_eof97;
case 97:
	switch( (*p) ) {
		case 95: goto tr38;
		case 97: goto st98;
		case 101: goto st105;
		case 105: goto st106;
		case 111: goto st107;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 98 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st98:
	if ( ++p == pe )
		goto _test_eof98;
case 98:
	switch( (*p) ) {
		case 95: goto tr38;
		case 109: goto st99;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st99:
	if ( ++p == pe )
		goto _test_eof99;
case 99:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st100;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st100:
	if ( ++p == pe )
		goto _test_eof100;
case 100:
	switch( (*p) ) {
		case 95: goto tr38;
		case 115: goto st101;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st101:
	if ( ++p == pe )
		goto _test_eof101;
case 101:
	switch( (*p) ) {
		case 95: goto tr38;
		case 112: goto st102;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st102:
	if ( ++p == pe )
		goto _test_eof102;
case 102:
	switch( (*p) ) {
		case 95: goto tr38;
		case 97: goto st103;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 98 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st103:
	if ( ++p == pe )
		goto _test_eof103;
case 103:
	switch( (*p) ) {
		case 95: goto tr38;
		case 99: goto st104;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st104:
	if ( ++p == pe )
		goto _test_eof104;
case 104:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto tr175;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st105:
	if ( ++p == pe )
		goto _test_eof105;
case 105:
	switch( (*p) ) {
		case 95: goto tr38;
		case 119: goto tr176;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st106:
	if ( ++p == pe )
		goto _test_eof106;
case 106:
	switch( (*p) ) {
		case 95: goto tr38;
		case 108: goto tr177;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st107:
	if ( ++p == pe )
		goto _test_eof107;
case 107:
	switch( (*p) ) {
		case 95: goto tr38;
		case 110: goto st108;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st108:
	if ( ++p == pe )
		goto _test_eof108;
case 108:
	switch( (*p) ) {
		case 95: goto tr38;
		case 97: goto st109;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 98 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st109:
	if ( ++p == pe )
		goto _test_eof109;
case 109:
	switch( (*p) ) {
		case 95: goto tr38;
		case 115: goto st110;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st110:
	if ( ++p == pe )
		goto _test_eof110;
case 110:
	switch( (*p) ) {
		case 95: goto tr38;
		case 115: goto st111;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st111:
	if ( ++p == pe )
		goto _test_eof111;
case 111:
	switch( (*p) ) {
		case 95: goto tr38;
		case 111: goto st112;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st112:
	if ( ++p == pe )
		goto _test_eof112;
case 112:
	switch( (*p) ) {
		case 95: goto tr38;
		case 99: goto tr183;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st113:
	if ( ++p == pe )
		goto _test_eof113;
case 113:
	switch( (*p) ) {
		case 95: goto tr38;
		case 97: goto st114;
		case 114: goto st122;
		case 116: goto st135;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 98 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st114:
	if ( ++p == pe )
		goto _test_eof114;
case 114:
	switch( (*p) ) {
		case 95: goto tr38;
		case 114: goto st115;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st115:
	if ( ++p == pe )
		goto _test_eof115;
case 115:
	switch( (*p) ) {
		case 95: goto tr38;
		case 115: goto st116;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st116:
	if ( ++p == pe )
		goto _test_eof116;
case 116:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st117;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st117:
	if ( ++p == pe )
		goto _test_eof117;
case 117:
	switch( (*p) ) {
		case 95: goto st118;
		case 114: goto tr192;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr190;
st118:
	if ( ++p == pe )
		goto _test_eof118;
case 118:
	switch( (*p) ) {
		case 95: goto tr38;
		case 115: goto st119;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st119:
	if ( ++p == pe )
		goto _test_eof119;
case 119:
	switch( (*p) ) {
		case 95: goto tr38;
		case 116: goto st120;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st120:
	if ( ++p == pe )
		goto _test_eof120;
case 120:
	switch( (*p) ) {
		case 95: goto tr38;
		case 111: goto st121;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st121:
	if ( ++p == pe )
		goto _test_eof121;
case 121:
	switch( (*p) ) {
		case 95: goto tr38;
		case 112: goto tr196;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st122:
	if ( ++p == pe )
		goto _test_eof122;
case 122:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st123;
		case 105: goto st126;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st123:
	if ( ++p == pe )
		goto _test_eof123;
case 123:
	switch( (*p) ) {
		case 95: goto tr38;
		case 99: goto tr199;
		case 101: goto st124;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st124:
	if ( ++p == pe )
		goto _test_eof124;
case 124:
	switch( (*p) ) {
		case 95: goto tr38;
		case 111: goto st125;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st125:
	if ( ++p == pe )
		goto _test_eof125;
case 125:
	switch( (*p) ) {
		case 95: goto tr38;
		case 102: goto tr202;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st126:
	if ( ++p == pe )
		goto _test_eof126;
case 126:
	switch( (*p) ) {
		case 95: goto tr38;
		case 110: goto st127;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st127:
	if ( ++p == pe )
		goto _test_eof127;
case 127:
	switch( (*p) ) {
		case 95: goto tr38;
		case 116: goto st128;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st128:
	if ( ++p == pe )
		goto _test_eof128;
case 128:
	switch( (*p) ) {
		case 95: goto st129;
		case 115: goto tr207;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr205;
st129:
	if ( ++p == pe )
		goto _test_eof129;
case 129:
	switch( (*p) ) {
		case 95: goto tr38;
		case 120: goto st130;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st130:
	if ( ++p == pe )
		goto _test_eof130;
case 130:
	switch( (*p) ) {
		case 95: goto tr38;
		case 109: goto st131;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st131:
	if ( ++p == pe )
		goto _test_eof131;
case 131:
	switch( (*p) ) {
		case 95: goto tr38;
		case 108: goto st132;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st132:
	if ( ++p == pe )
		goto _test_eof132;
case 132:
	if ( (*p) == 95 )
		goto st133;
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr211;
st133:
	if ( ++p == pe )
		goto _test_eof133;
case 133:
	switch( (*p) ) {
		case 95: goto tr38;
		case 97: goto st134;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 98 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st134:
	if ( ++p == pe )
		goto _test_eof134;
case 134:
	switch( (*p) ) {
		case 95: goto tr38;
		case 99: goto tr214;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st135:
	if ( ++p == pe )
		goto _test_eof135;
case 135:
	switch( (*p) ) {
		case 95: goto tr38;
		case 114: goto tr215;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st136:
	if ( ++p == pe )
		goto _test_eof136;
case 136:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st137;
		case 105: goto st156;
		case 108: goto tr218;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st137:
	if ( ++p == pe )
		goto _test_eof137;
case 137:
	switch( (*p) ) {
		case 95: goto tr38;
		case 100: goto st138;
		case 102: goto tr220;
		case 106: goto st146;
		case 113: goto st149;
		case 116: goto st153;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st138:
	if ( ++p == pe )
		goto _test_eof138;
case 138:
	switch( (*p) ) {
		case 95: goto tr38;
		case 117: goto st139;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st139:
	if ( ++p == pe )
		goto _test_eof139;
case 139:
	switch( (*p) ) {
		case 95: goto tr38;
		case 99: goto st140;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st140:
	if ( ++p == pe )
		goto _test_eof140;
case 140:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st141;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st141:
	if ( ++p == pe )
		goto _test_eof141;
case 141:
	switch( (*p) ) {
		case 95: goto tr38;
		case 102: goto st142;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st142:
	if ( ++p == pe )
		goto _test_eof142;
case 142:
	switch( (*p) ) {
		case 95: goto tr38;
		case 105: goto st143;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st143:
	if ( ++p == pe )
		goto _test_eof143;
case 143:
	switch( (*p) ) {
		case 95: goto tr38;
		case 114: goto st144;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st144:
	if ( ++p == pe )
		goto _test_eof144;
case 144:
	switch( (*p) ) {
		case 95: goto tr38;
		case 115: goto st145;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st145:
	if ( ++p == pe )
		goto _test_eof145;
case 145:
	switch( (*p) ) {
		case 95: goto tr38;
		case 116: goto tr231;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st146:
	if ( ++p == pe )
		goto _test_eof146;
case 146:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st147;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st147:
	if ( ++p == pe )
		goto _test_eof147;
case 147:
	switch( (*p) ) {
		case 95: goto tr38;
		case 99: goto st148;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st148:
	if ( ++p == pe )
		goto _test_eof148;
case 148:
	switch( (*p) ) {
		case 95: goto tr38;
		case 116: goto tr234;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st149:
	if ( ++p == pe )
		goto _test_eof149;
case 149:
	switch( (*p) ) {
		case 95: goto tr38;
		case 117: goto st150;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st150:
	if ( ++p == pe )
		goto _test_eof150;
case 150:
	switch( (*p) ) {
		case 95: goto tr38;
		case 105: goto st151;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st151:
	if ( ++p == pe )
		goto _test_eof151;
case 151:
	switch( (*p) ) {
		case 95: goto tr38;
		case 114: goto st152;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st152:
	if ( ++p == pe )
		goto _test_eof152;
case 152:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto tr238;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st153:
	if ( ++p == pe )
		goto _test_eof153;
case 153:
	switch( (*p) ) {
		case 95: goto tr38;
		case 117: goto st154;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st154:
	if ( ++p == pe )
		goto _test_eof154;
case 154:
	switch( (*p) ) {
		case 95: goto tr38;
		case 114: goto st155;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st155:
	if ( ++p == pe )
		goto _test_eof155;
case 155:
	switch( (*p) ) {
		case 95: goto tr38;
		case 110: goto tr241;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st156:
	if ( ++p == pe )
		goto _test_eof156;
case 156:
	switch( (*p) ) {
		case 95: goto tr38;
		case 103: goto st157;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st157:
	if ( ++p == pe )
		goto _test_eof157;
case 157:
	switch( (*p) ) {
		case 95: goto tr38;
		case 104: goto st158;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st158:
	if ( ++p == pe )
		goto _test_eof158;
case 158:
	switch( (*p) ) {
		case 95: goto tr38;
		case 116: goto tr244;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st159:
	if ( ++p == pe )
		goto _test_eof159;
case 159:
	switch( (*p) ) {
		case 95: goto tr38;
		case 111: goto st160;
		case 114: goto st163;
		case 121: goto st165;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st160:
	if ( ++p == pe )
		goto _test_eof160;
case 160:
	switch( (*p) ) {
		case 95: goto tr38;
		case 107: goto st161;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st161:
	if ( ++p == pe )
		goto _test_eof161;
case 161:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st162;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st162:
	if ( ++p == pe )
		goto _test_eof162;
case 162:
	switch( (*p) ) {
		case 95: goto tr38;
		case 110: goto tr250;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st163:
	if ( ++p == pe )
		goto _test_eof163;
case 163:
	switch( (*p) ) {
		case 95: goto tr38;
		case 117: goto st164;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st164:
	if ( ++p == pe )
		goto _test_eof164;
case 164:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto tr252;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st165:
	if ( ++p == pe )
		goto _test_eof165;
case 165:
	switch( (*p) ) {
		case 95: goto tr38;
		case 112: goto st166;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st166:
	if ( ++p == pe )
		goto _test_eof166;
case 166:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st167;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st167:
	if ( ++p == pe )
		goto _test_eof167;
case 167:
	switch( (*p) ) {
		case 95: goto tr38;
		case 105: goto st168;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st168:
	if ( ++p == pe )
		goto _test_eof168;
case 168:
	switch( (*p) ) {
		case 95: goto tr38;
		case 100: goto tr256;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st169:
	if ( ++p == pe )
		goto _test_eof169;
case 169:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st170;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st170:
	if ( ++p == pe )
		goto _test_eof170;
case 170:
	switch( (*p) ) {
		case 95: goto tr38;
		case 99: goto st171;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st171:
	if ( ++p == pe )
		goto _test_eof171;
case 171:
	switch( (*p) ) {
		case 95: goto tr38;
		case 116: goto st172;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st172:
	if ( ++p == pe )
		goto _test_eof172;
case 172:
	switch( (*p) ) {
		case 95: goto tr38;
		case 111: goto st173;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st173:
	if ( ++p == pe )
		goto _test_eof173;
case 173:
	switch( (*p) ) {
		case 95: goto tr38;
		case 114: goto tr261;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st174:
	if ( ++p == pe )
		goto _test_eof174;
case 174:
	switch( (*p) ) {
		case 95: goto tr38;
		case 104: goto st175;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st175:
	if ( ++p == pe )
		goto _test_eof175;
case 175:
	switch( (*p) ) {
		case 95: goto tr38;
		case 105: goto st176;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st176:
	if ( ++p == pe )
		goto _test_eof176;
case 176:
	switch( (*p) ) {
		case 95: goto tr38;
		case 108: goto st177;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st177:
	if ( ++p == pe )
		goto _test_eof177;
case 177:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto tr265;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st178:
	if ( ++p == pe )
		goto _test_eof178;
case 178:
	switch( (*p) ) {
		case 95: goto tr38;
		case 105: goto st179;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st179:
	if ( ++p == pe )
		goto _test_eof179;
case 179:
	switch( (*p) ) {
		case 95: goto tr38;
		case 101: goto st180;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st180:
	if ( ++p == pe )
		goto _test_eof180;
case 180:
	switch( (*p) ) {
		case 95: goto tr38;
		case 108: goto st181;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st181:
	if ( ++p == pe )
		goto _test_eof181;
case 181:
	switch( (*p) ) {
		case 95: goto tr38;
		case 100: goto tr269;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr38;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr38;
	} else
		goto tr38;
	goto tr74;
st182:
	if ( ++p == pe )
		goto _test_eof182;
case 182:
	if ( (*p) == 124 )
		goto tr270;
	goto tr61;
tr59:
#line 1 "NONE"
	{te = p+1;}
	goto st183;
st183:
	if ( ++p == pe )
		goto _test_eof183;
case 183:
#line 4193 "lmscan.cpp"
	if ( (*p) == 10 )
		goto tr8;
	goto st3;
st3:
	if ( ++p == pe )
		goto _test_eof3;
case 3:
	if ( (*p) == 10 )
		goto tr8;
	goto st3;
tr271:
#line 334 "lmscan.rl"
	{te = p+1;{ token( TK_ReChar, ts, te ); }}
	goto st184;
tr272:
#line 329 "lmscan.rl"
	{te = p+1;{
			scan_error() << "unterminated OR literal" << endl;
		}}
	goto st184;
tr273:
#line 324 "lmscan.rl"
	{te = p+1;{ token( TK_Dash, 0, 0 ); }}
	goto st184;
tr275:
#line 327 "lmscan.rl"
	{te = p+1;{ token( TK_SqClose ); {cs = stack[--top];goto _again;} }}
	goto st184;
tr276:
#line 334 "lmscan.rl"
	{te = p;p--;{ token( TK_ReChar, ts, te ); }}
	goto st184;
tr277:
#line 321 "lmscan.rl"
	{te = p+1;{ token( TK_ReChar, ts+1, te ); }}
	goto st184;
tr278:
#line 320 "lmscan.rl"
	{te = p+1;{ updateCol(); }}
	goto st184;
tr279:
#line 312 "lmscan.rl"
	{te = p+1;{ token( TK_ReChar, '\0' ); }}
	goto st184;
tr280:
#line 313 "lmscan.rl"
	{te = p+1;{ token( TK_ReChar, '\a' ); }}
	goto st184;
tr281:
#line 314 "lmscan.rl"
	{te = p+1;{ token( TK_ReChar, '\b' ); }}
	goto st184;
tr282:
#line 318 "lmscan.rl"
	{te = p+1;{ token( TK_ReChar, '\f' ); }}
	goto st184;
tr283:
#line 316 "lmscan.rl"
	{te = p+1;{ token( TK_ReChar, '\n' ); }}
	goto st184;
tr284:
#line 319 "lmscan.rl"
	{te = p+1;{ token( TK_ReChar, '\r' ); }}
	goto st184;
tr285:
#line 315 "lmscan.rl"
	{te = p+1;{ token( TK_ReChar, '\t' ); }}
	goto st184;
tr286:
#line 317 "lmscan.rl"
	{te = p+1;{ token( TK_ReChar, '\v' ); }}
	goto st184;
st184:
#line 1 "NONE"
	{ts = 0;}
	if ( ++p == pe )
		goto _test_eof184;
case 184:
#line 1 "NONE"
	{ts = p;}
#line 4274 "lmscan.cpp"
	switch( (*p) ) {
		case 0: goto tr272;
		case 45: goto tr273;
		case 92: goto st185;
		case 93: goto tr275;
	}
	goto tr271;
st185:
	if ( ++p == pe )
		goto _test_eof185;
case 185:
	switch( (*p) ) {
		case 10: goto tr278;
		case 48: goto tr279;
		case 97: goto tr280;
		case 98: goto tr281;
		case 102: goto tr282;
		case 110: goto tr283;
		case 114: goto tr284;
		case 116: goto tr285;
		case 118: goto tr286;
	}
	goto tr277;
tr9:
#line 375 "lmscan.rl"
	{{p = ((te))-1;}{ token( *ts ); }}
	goto st186;
tr15:
#line 291 "lmscan.rl"
	{ 
		lastnl = p; 
		column = 0;
		line++;
	}
#line 356 "lmscan.rl"
	{te = p+1;{ updateCol(); }}
	goto st186;
tr19:
#line 343 "lmscan.rl"
	{{p = ((te))-1;}{ token( TK_UInt, ts, te ); }}
	goto st186;
tr287:
#line 375 "lmscan.rl"
	{te = p+1;{ token( *ts ); }}
	goto st186;
tr288:
#line 373 "lmscan.rl"
	{te = p+1;}
	goto st186;
tr290:
#line 291 "lmscan.rl"
	{ 
		lastnl = p; 
		column = 0;
		line++;
	}
#line 370 "lmscan.rl"
	{te = p+1;{ updateCol(); }}
	goto st186;
tr297:
#line 353 "lmscan.rl"
	{te = p+1;{ token( '/'); {cs = stack[--top];goto _again;} }}
	goto st186;
tr304:
#line 367 "lmscan.rl"
	{te = p;p--;{ updateCol(); }}
	goto st186;
tr305:
#line 375 "lmscan.rl"
	{te = p;p--;{ token( *ts ); }}
	goto st186;
tr306:
#line 348 "lmscan.rl"
	{te = p;p--;{ token( TK_Literal, ts, te ); }}
	goto st186;
tr307:
#line 348 "lmscan.rl"
	{te = p+1;{ token( TK_Literal, ts, te ); }}
	goto st186;
tr308:
#line 359 "lmscan.rl"
	{te = p+1;{ token( TK_StarStar ); }}
	goto st186;
tr309:
#line 360 "lmscan.rl"
	{te = p+1;{ token( TK_DashDash ); }}
	goto st186;
tr310:
#line 358 "lmscan.rl"
	{te = p+1;{ token( TK_DotDot ); }}
	goto st186;
tr311:
#line 343 "lmscan.rl"
	{te = p;p--;{ token( TK_UInt, ts, te ); }}
	goto st186;
tr313:
#line 344 "lmscan.rl"
	{te = p;p--;{ token( TK_Hex, ts, te ); }}
	goto st186;
tr315:
#line 362 "lmscan.rl"
	{te = p;p--;{ token( TK_ColonGt ); }}
	goto st186;
tr316:
#line 363 "lmscan.rl"
	{te = p+1;{ token( TK_ColonGtGt ); }}
	goto st186;
tr317:
#line 364 "lmscan.rl"
	{te = p+1;{ token( TK_LtColon ); }}
	goto st186;
tr318:
#line 340 "lmscan.rl"
	{te = p;p--;{ token( TK_Word, ts, te ); }}
	goto st186;
tr319:
#line 350 "lmscan.rl"
	{te = p;p--;{ token( TK_SqOpen ); {stack[top++] = 186; goto st184;} }}
	goto st186;
tr320:
#line 351 "lmscan.rl"
	{te = p+1;{ token( TK_SqOpenNeg ); {stack[top++] = 186; goto st184;} }}
	goto st186;
st186:
#line 1 "NONE"
	{ts = 0;}
	if ( ++p == pe )
		goto _test_eof186;
case 186:
#line 1 "NONE"
	{ts = p;}
#line 4406 "lmscan.cpp"
	switch( (*p) ) {
		case 0: goto tr288;
		case 9: goto st187;
		case 10: goto tr290;
		case 13: goto st187;
		case 32: goto st187;
		case 34: goto tr291;
		case 35: goto tr292;
		case 39: goto tr293;
		case 42: goto st192;
		case 45: goto st193;
		case 46: goto st194;
		case 47: goto tr297;
		case 48: goto tr298;
		case 58: goto st198;
		case 60: goto st200;
		case 91: goto st202;
		case 95: goto st201;
	}
	if ( (*p) < 65 ) {
		if ( 49 <= (*p) && (*p) <= 57 )
			goto st196;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto st201;
	} else
		goto st201;
	goto tr287;
st187:
	if ( ++p == pe )
		goto _test_eof187;
case 187:
	switch( (*p) ) {
		case 9: goto st187;
		case 13: goto st187;
		case 32: goto st187;
	}
	goto tr304;
tr291:
#line 1 "NONE"
	{te = p+1;}
	goto st188;
st188:
	if ( ++p == pe )
		goto _test_eof188;
case 188:
#line 4453 "lmscan.cpp"
	switch( (*p) ) {
		case 10: goto tr11;
		case 34: goto st189;
		case 92: goto st5;
	}
	goto st4;
tr11:
#line 291 "lmscan.rl"
	{ 
		lastnl = p; 
		column = 0;
		line++;
	}
	goto st4;
st4:
	if ( ++p == pe )
		goto _test_eof4;
case 4:
#line 4472 "lmscan.cpp"
	switch( (*p) ) {
		case 10: goto tr11;
		case 34: goto st189;
		case 92: goto st5;
	}
	goto st4;
st189:
	if ( ++p == pe )
		goto _test_eof189;
case 189:
	if ( (*p) == 105 )
		goto tr307;
	goto tr306;
st5:
	if ( ++p == pe )
		goto _test_eof5;
case 5:
	if ( (*p) == 10 )
		goto tr11;
	goto st4;
tr292:
#line 1 "NONE"
	{te = p+1;}
	goto st190;
st190:
	if ( ++p == pe )
		goto _test_eof190;
case 190:
#line 4501 "lmscan.cpp"
	if ( (*p) == 10 )
		goto tr15;
	goto st6;
st6:
	if ( ++p == pe )
		goto _test_eof6;
case 6:
	if ( (*p) == 10 )
		goto tr15;
	goto st6;
tr293:
#line 1 "NONE"
	{te = p+1;}
	goto st191;
st191:
	if ( ++p == pe )
		goto _test_eof191;
case 191:
#line 4520 "lmscan.cpp"
	switch( (*p) ) {
		case 10: goto tr17;
		case 39: goto st189;
		case 92: goto st8;
	}
	goto st7;
tr17:
#line 291 "lmscan.rl"
	{ 
		lastnl = p; 
		column = 0;
		line++;
	}
	goto st7;
st7:
	if ( ++p == pe )
		goto _test_eof7;
case 7:
#line 4539 "lmscan.cpp"
	switch( (*p) ) {
		case 10: goto tr17;
		case 39: goto st189;
		case 92: goto st8;
	}
	goto st7;
st8:
	if ( ++p == pe )
		goto _test_eof8;
case 8:
	if ( (*p) == 10 )
		goto tr17;
	goto st7;
st192:
	if ( ++p == pe )
		goto _test_eof192;
case 192:
	if ( (*p) == 42 )
		goto tr308;
	goto tr305;
st193:
	if ( ++p == pe )
		goto _test_eof193;
case 193:
	if ( (*p) == 45 )
		goto tr309;
	goto tr305;
st194:
	if ( ++p == pe )
		goto _test_eof194;
case 194:
	if ( (*p) == 46 )
		goto tr310;
	goto tr305;
tr298:
#line 1 "NONE"
	{te = p+1;}
	goto st195;
st195:
	if ( ++p == pe )
		goto _test_eof195;
case 195:
#line 4582 "lmscan.cpp"
	if ( (*p) == 120 )
		goto st9;
	if ( 48 <= (*p) && (*p) <= 57 )
		goto st196;
	goto tr311;
st196:
	if ( ++p == pe )
		goto _test_eof196;
case 196:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto st196;
	goto tr311;
st9:
	if ( ++p == pe )
		goto _test_eof9;
case 9:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto st197;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto st197;
	} else
		goto st197;
	goto tr19;
st197:
	if ( ++p == pe )
		goto _test_eof197;
case 197:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto st197;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto st197;
	} else
		goto st197;
	goto tr313;
st198:
	if ( ++p == pe )
		goto _test_eof198;
case 198:
	if ( (*p) == 62 )
		goto st199;
	goto tr305;
st199:
	if ( ++p == pe )
		goto _test_eof199;
case 199:
	if ( (*p) == 62 )
		goto tr316;
	goto tr315;
st200:
	if ( ++p == pe )
		goto _test_eof200;
case 200:
	if ( (*p) == 58 )
		goto tr317;
	goto tr305;
st201:
	if ( ++p == pe )
		goto _test_eof201;
case 201:
	if ( (*p) == 95 )
		goto st201;
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto st201;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto st201;
	} else
		goto st201;
	goto tr318;
st202:
	if ( ++p == pe )
		goto _test_eof202;
case 202:
	if ( (*p) == 94 )
		goto tr320;
	goto tr319;
tr321:
#line 413 "lmscan.rl"
	{te = p+1;{ 
			litBuf.append( *ts );
		}}
	goto st203;
tr322:
#line 291 "lmscan.rl"
	{ 
		lastnl = p; 
		column = 0;
		line++;
	}
#line 398 "lmscan.rl"
	{te = p+1;{
			litBuf.append( '\n' );
			token( TK_LitPat, litBuf.data, litBuf.data+litBuf.length );
			litBuf.clear();
			token( '"' );
			{cs = stack[--top];goto _again;}
		}}
	goto st203;
tr323:
#line 390 "lmscan.rl"
	{te = p+1;{
			if ( litBuf.length > 0 ) {
				token( TK_LitPat, litBuf.data, litBuf.data+litBuf.length );
				litBuf.clear();
			}
			token( '"' );
			{cs = stack[--top];goto _again;}
		}}
	goto st203;
tr324:
#line 405 "lmscan.rl"
	{te = p+1;{ 
			if ( litBuf.length > 0 ) {
				token( TK_LitPat, litBuf.data, litBuf.data+litBuf.length );
				litBuf.clear();
			}
			token( '[' );
			{stack[top++] = 203; goto st10;}
		}}
	goto st203;
tr326:
#line 413 "lmscan.rl"
	{te = p;p--;{ 
			litBuf.append( *ts );
		}}
	goto st203;
tr327:
#line 387 "lmscan.rl"
	{te = p+1;{
			litBuf.append( ts[1] );
		}}
	goto st203;
tr328:
#line 379 "lmscan.rl"
	{te = p+1;{ litBuf.append( '\a' ); }}
	goto st203;
tr329:
#line 380 "lmscan.rl"
	{te = p+1;{ litBuf.append( '\b' ); }}
	goto st203;
tr330:
#line 384 "lmscan.rl"
	{te = p+1;{ litBuf.append( '\f' ); }}
	goto st203;
tr331:
#line 382 "lmscan.rl"
	{te = p+1;{ litBuf.append( '\n' ); }}
	goto st203;
tr332:
#line 385 "lmscan.rl"
	{te = p+1;{ litBuf.append( '\r' ); }}
	goto st203;
tr333:
#line 381 "lmscan.rl"
	{te = p+1;{ litBuf.append( '\t' ); }}
	goto st203;
tr334:
#line 383 "lmscan.rl"
	{te = p+1;{ litBuf.append( '\v' ); }}
	goto st203;
st203:
#line 1 "NONE"
	{ts = 0;}
	if ( ++p == pe )
		goto _test_eof203;
case 203:
#line 1 "NONE"
	{ts = p;}
#line 4756 "lmscan.cpp"
	switch( (*p) ) {
		case 10: goto tr322;
		case 34: goto tr323;
		case 91: goto tr324;
		case 92: goto st204;
	}
	goto tr321;
st204:
	if ( ++p == pe )
		goto _test_eof204;
case 204:
	switch( (*p) ) {
		case 97: goto tr328;
		case 98: goto tr329;
		case 102: goto tr330;
		case 110: goto tr331;
		case 114: goto tr332;
		case 116: goto tr333;
		case 118: goto tr334;
	}
	goto tr327;
	}
	_test_eof10: cs = 10; goto _test_eof; 
	_test_eof11: cs = 11; goto _test_eof; 
	_test_eof12: cs = 12; goto _test_eof; 
	_test_eof13: cs = 13; goto _test_eof; 
	_test_eof0: cs = 0; goto _test_eof; 
	_test_eof14: cs = 14; goto _test_eof; 
	_test_eof15: cs = 15; goto _test_eof; 
	_test_eof1: cs = 1; goto _test_eof; 
	_test_eof2: cs = 2; goto _test_eof; 
	_test_eof16: cs = 16; goto _test_eof; 
	_test_eof17: cs = 17; goto _test_eof; 
	_test_eof18: cs = 18; goto _test_eof; 
	_test_eof19: cs = 19; goto _test_eof; 
	_test_eof20: cs = 20; goto _test_eof; 
	_test_eof21: cs = 21; goto _test_eof; 
	_test_eof22: cs = 22; goto _test_eof; 
	_test_eof23: cs = 23; goto _test_eof; 
	_test_eof24: cs = 24; goto _test_eof; 
	_test_eof25: cs = 25; goto _test_eof; 
	_test_eof26: cs = 26; goto _test_eof; 
	_test_eof27: cs = 27; goto _test_eof; 
	_test_eof28: cs = 28; goto _test_eof; 
	_test_eof29: cs = 29; goto _test_eof; 
	_test_eof30: cs = 30; goto _test_eof; 
	_test_eof31: cs = 31; goto _test_eof; 
	_test_eof32: cs = 32; goto _test_eof; 
	_test_eof33: cs = 33; goto _test_eof; 
	_test_eof34: cs = 34; goto _test_eof; 
	_test_eof35: cs = 35; goto _test_eof; 
	_test_eof36: cs = 36; goto _test_eof; 
	_test_eof37: cs = 37; goto _test_eof; 
	_test_eof38: cs = 38; goto _test_eof; 
	_test_eof39: cs = 39; goto _test_eof; 
	_test_eof40: cs = 40; goto _test_eof; 
	_test_eof41: cs = 41; goto _test_eof; 
	_test_eof42: cs = 42; goto _test_eof; 
	_test_eof43: cs = 43; goto _test_eof; 
	_test_eof44: cs = 44; goto _test_eof; 
	_test_eof45: cs = 45; goto _test_eof; 
	_test_eof46: cs = 46; goto _test_eof; 
	_test_eof47: cs = 47; goto _test_eof; 
	_test_eof48: cs = 48; goto _test_eof; 
	_test_eof49: cs = 49; goto _test_eof; 
	_test_eof50: cs = 50; goto _test_eof; 
	_test_eof51: cs = 51; goto _test_eof; 
	_test_eof52: cs = 52; goto _test_eof; 
	_test_eof53: cs = 53; goto _test_eof; 
	_test_eof54: cs = 54; goto _test_eof; 
	_test_eof55: cs = 55; goto _test_eof; 
	_test_eof56: cs = 56; goto _test_eof; 
	_test_eof57: cs = 57; goto _test_eof; 
	_test_eof58: cs = 58; goto _test_eof; 
	_test_eof59: cs = 59; goto _test_eof; 
	_test_eof60: cs = 60; goto _test_eof; 
	_test_eof61: cs = 61; goto _test_eof; 
	_test_eof62: cs = 62; goto _test_eof; 
	_test_eof63: cs = 63; goto _test_eof; 
	_test_eof64: cs = 64; goto _test_eof; 
	_test_eof65: cs = 65; goto _test_eof; 
	_test_eof66: cs = 66; goto _test_eof; 
	_test_eof67: cs = 67; goto _test_eof; 
	_test_eof68: cs = 68; goto _test_eof; 
	_test_eof69: cs = 69; goto _test_eof; 
	_test_eof70: cs = 70; goto _test_eof; 
	_test_eof71: cs = 71; goto _test_eof; 
	_test_eof72: cs = 72; goto _test_eof; 
	_test_eof73: cs = 73; goto _test_eof; 
	_test_eof74: cs = 74; goto _test_eof; 
	_test_eof75: cs = 75; goto _test_eof; 
	_test_eof76: cs = 76; goto _test_eof; 
	_test_eof77: cs = 77; goto _test_eof; 
	_test_eof78: cs = 78; goto _test_eof; 
	_test_eof79: cs = 79; goto _test_eof; 
	_test_eof80: cs = 80; goto _test_eof; 
	_test_eof81: cs = 81; goto _test_eof; 
	_test_eof82: cs = 82; goto _test_eof; 
	_test_eof83: cs = 83; goto _test_eof; 
	_test_eof84: cs = 84; goto _test_eof; 
	_test_eof85: cs = 85; goto _test_eof; 
	_test_eof86: cs = 86; goto _test_eof; 
	_test_eof87: cs = 87; goto _test_eof; 
	_test_eof88: cs = 88; goto _test_eof; 
	_test_eof89: cs = 89; goto _test_eof; 
	_test_eof90: cs = 90; goto _test_eof; 
	_test_eof91: cs = 91; goto _test_eof; 
	_test_eof92: cs = 92; goto _test_eof; 
	_test_eof93: cs = 93; goto _test_eof; 
	_test_eof94: cs = 94; goto _test_eof; 
	_test_eof95: cs = 95; goto _test_eof; 
	_test_eof96: cs = 96; goto _test_eof; 
	_test_eof97: cs = 97; goto _test_eof; 
	_test_eof98: cs = 98; goto _test_eof; 
	_test_eof99: cs = 99; goto _test_eof; 
	_test_eof100: cs = 100; goto _test_eof; 
	_test_eof101: cs = 101; goto _test_eof; 
	_test_eof102: cs = 102; goto _test_eof; 
	_test_eof103: cs = 103; goto _test_eof; 
	_test_eof104: cs = 104; goto _test_eof; 
	_test_eof105: cs = 105; goto _test_eof; 
	_test_eof106: cs = 106; goto _test_eof; 
	_test_eof107: cs = 107; goto _test_eof; 
	_test_eof108: cs = 108; goto _test_eof; 
	_test_eof109: cs = 109; goto _test_eof; 
	_test_eof110: cs = 110; goto _test_eof; 
	_test_eof111: cs = 111; goto _test_eof; 
	_test_eof112: cs = 112; goto _test_eof; 
	_test_eof113: cs = 113; goto _test_eof; 
	_test_eof114: cs = 114; goto _test_eof; 
	_test_eof115: cs = 115; goto _test_eof; 
	_test_eof116: cs = 116; goto _test_eof; 
	_test_eof117: cs = 117; goto _test_eof; 
	_test_eof118: cs = 118; goto _test_eof; 
	_test_eof119: cs = 119; goto _test_eof; 
	_test_eof120: cs = 120; goto _test_eof; 
	_test_eof121: cs = 121; goto _test_eof; 
	_test_eof122: cs = 122; goto _test_eof; 
	_test_eof123: cs = 123; goto _test_eof; 
	_test_eof124: cs = 124; goto _test_eof; 
	_test_eof125: cs = 125; goto _test_eof; 
	_test_eof126: cs = 126; goto _test_eof; 
	_test_eof127: cs = 127; goto _test_eof; 
	_test_eof128: cs = 128; goto _test_eof; 
	_test_eof129: cs = 129; goto _test_eof; 
	_test_eof130: cs = 130; goto _test_eof; 
	_test_eof131: cs = 131; goto _test_eof; 
	_test_eof132: cs = 132; goto _test_eof; 
	_test_eof133: cs = 133; goto _test_eof; 
	_test_eof134: cs = 134; goto _test_eof; 
	_test_eof135: cs = 135; goto _test_eof; 
	_test_eof136: cs = 136; goto _test_eof; 
	_test_eof137: cs = 137; goto _test_eof; 
	_test_eof138: cs = 138; goto _test_eof; 
	_test_eof139: cs = 139; goto _test_eof; 
	_test_eof140: cs = 140; goto _test_eof; 
	_test_eof141: cs = 141; goto _test_eof; 
	_test_eof142: cs = 142; goto _test_eof; 
	_test_eof143: cs = 143; goto _test_eof; 
	_test_eof144: cs = 144; goto _test_eof; 
	_test_eof145: cs = 145; goto _test_eof; 
	_test_eof146: cs = 146; goto _test_eof; 
	_test_eof147: cs = 147; goto _test_eof; 
	_test_eof148: cs = 148; goto _test_eof; 
	_test_eof149: cs = 149; goto _test_eof; 
	_test_eof150: cs = 150; goto _test_eof; 
	_test_eof151: cs = 151; goto _test_eof; 
	_test_eof152: cs = 152; goto _test_eof; 
	_test_eof153: cs = 153; goto _test_eof; 
	_test_eof154: cs = 154; goto _test_eof; 
	_test_eof155: cs = 155; goto _test_eof; 
	_test_eof156: cs = 156; goto _test_eof; 
	_test_eof157: cs = 157; goto _test_eof; 
	_test_eof158: cs = 158; goto _test_eof; 
	_test_eof159: cs = 159; goto _test_eof; 
	_test_eof160: cs = 160; goto _test_eof; 
	_test_eof161: cs = 161; goto _test_eof; 
	_test_eof162: cs = 162; goto _test_eof; 
	_test_eof163: cs = 163; goto _test_eof; 
	_test_eof164: cs = 164; goto _test_eof; 
	_test_eof165: cs = 165; goto _test_eof; 
	_test_eof166: cs = 166; goto _test_eof; 
	_test_eof167: cs = 167; goto _test_eof; 
	_test_eof168: cs = 168; goto _test_eof; 
	_test_eof169: cs = 169; goto _test_eof; 
	_test_eof170: cs = 170; goto _test_eof; 
	_test_eof171: cs = 171; goto _test_eof; 
	_test_eof172: cs = 172; goto _test_eof; 
	_test_eof173: cs = 173; goto _test_eof; 
	_test_eof174: cs = 174; goto _test_eof; 
	_test_eof175: cs = 175; goto _test_eof; 
	_test_eof176: cs = 176; goto _test_eof; 
	_test_eof177: cs = 177; goto _test_eof; 
	_test_eof178: cs = 178; goto _test_eof; 
	_test_eof179: cs = 179; goto _test_eof; 
	_test_eof180: cs = 180; goto _test_eof; 
	_test_eof181: cs = 181; goto _test_eof; 
	_test_eof182: cs = 182; goto _test_eof; 
	_test_eof183: cs = 183; goto _test_eof; 
	_test_eof3: cs = 3; goto _test_eof; 
	_test_eof184: cs = 184; goto _test_eof; 
	_test_eof185: cs = 185; goto _test_eof; 
	_test_eof186: cs = 186; goto _test_eof; 
	_test_eof187: cs = 187; goto _test_eof; 
	_test_eof188: cs = 188; goto _test_eof; 
	_test_eof4: cs = 4; goto _test_eof; 
	_test_eof189: cs = 189; goto _test_eof; 
	_test_eof5: cs = 5; goto _test_eof; 
	_test_eof190: cs = 190; goto _test_eof; 
	_test_eof6: cs = 6; goto _test_eof; 
	_test_eof191: cs = 191; goto _test_eof; 
	_test_eof7: cs = 7; goto _test_eof; 
	_test_eof8: cs = 8; goto _test_eof; 
	_test_eof192: cs = 192; goto _test_eof; 
	_test_eof193: cs = 193; goto _test_eof; 
	_test_eof194: cs = 194; goto _test_eof; 
	_test_eof195: cs = 195; goto _test_eof; 
	_test_eof196: cs = 196; goto _test_eof; 
	_test_eof9: cs = 9; goto _test_eof; 
	_test_eof197: cs = 197; goto _test_eof; 
	_test_eof198: cs = 198; goto _test_eof; 
	_test_eof199: cs = 199; goto _test_eof; 
	_test_eof200: cs = 200; goto _test_eof; 
	_test_eof201: cs = 201; goto _test_eof; 
	_test_eof202: cs = 202; goto _test_eof; 
	_test_eof203: cs = 203; goto _test_eof; 
	_test_eof204: cs = 204; goto _test_eof; 

	_test_eof: {}
	if ( p == eof )
	{
	switch ( cs ) {
	case 11: goto tr60;
	case 12: goto tr61;
	case 13: goto tr61;
	case 0: goto tr0;
	case 14: goto tr61;
	case 15: goto tr61;
	case 1: goto tr0;
	case 2: goto tr0;
	case 16: goto tr64;
	case 17: goto tr66;
	case 18: goto tr61;
	case 19: goto tr61;
	case 20: goto tr61;
	case 21: goto tr61;
	case 22: goto tr73;
	case 23: goto tr74;
	case 24: goto tr74;
	case 25: goto tr74;
	case 26: goto tr74;
	case 27: goto tr74;
	case 28: goto tr74;
	case 29: goto tr74;
	case 30: goto tr74;
	case 31: goto tr74;
	case 32: goto tr74;
	case 33: goto tr74;
	case 34: goto tr74;
	case 35: goto tr74;
	case 36: goto tr74;
	case 37: goto tr91;
	case 38: goto tr74;
	case 39: goto tr74;
	case 40: goto tr74;
	case 41: goto tr74;
	case 42: goto tr74;
	case 43: goto tr74;
	case 44: goto tr74;
	case 45: goto tr74;
	case 46: goto tr74;
	case 47: goto tr74;
	case 48: goto tr74;
	case 49: goto tr74;
	case 50: goto tr74;
	case 51: goto tr74;
	case 52: goto tr74;
	case 53: goto tr74;
	case 54: goto tr74;
	case 55: goto tr74;
	case 56: goto tr74;
	case 57: goto tr74;
	case 58: goto tr74;
	case 59: goto tr74;
	case 60: goto tr74;
	case 61: goto tr74;
	case 62: goto tr74;
	case 63: goto tr74;
	case 64: goto tr74;
	case 65: goto tr74;
	case 66: goto tr74;
	case 67: goto tr74;
	case 68: goto tr129;
	case 69: goto tr74;
	case 70: goto tr74;
	case 71: goto tr74;
	case 72: goto tr74;
	case 73: goto tr74;
	case 74: goto tr74;
	case 75: goto tr74;
	case 76: goto tr74;
	case 77: goto tr74;
	case 78: goto tr74;
	case 79: goto tr74;
	case 80: goto tr74;
	case 81: goto tr74;
	case 82: goto tr74;
	case 83: goto tr74;
	case 84: goto tr74;
	case 85: goto tr74;
	case 86: goto tr74;
	case 87: goto tr74;
	case 88: goto tr74;
	case 89: goto tr74;
	case 90: goto tr74;
	case 91: goto tr74;
	case 92: goto tr74;
	case 93: goto tr74;
	case 94: goto tr74;
	case 95: goto tr74;
	case 96: goto tr74;
	case 97: goto tr74;
	case 98: goto tr74;
	case 99: goto tr74;
	case 100: goto tr74;
	case 101: goto tr74;
	case 102: goto tr74;
	case 103: goto tr74;
	case 104: goto tr74;
	case 105: goto tr74;
	case 106: goto tr74;
	case 107: goto tr74;
	case 108: goto tr74;
	case 109: goto tr74;
	case 110: goto tr74;
	case 111: goto tr74;
	case 112: goto tr74;
	case 113: goto tr74;
	case 114: goto tr74;
	case 115: goto tr74;
	case 116: goto tr74;
	case 117: goto tr190;
	case 118: goto tr74;
	case 119: goto tr74;
	case 120: goto tr74;
	case 121: goto tr74;
	case 122: goto tr74;
	case 123: goto tr74;
	case 124: goto tr74;
	case 125: goto tr74;
	case 126: goto tr74;
	case 127: goto tr74;
	case 128: goto tr205;
	case 129: goto tr74;
	case 130: goto tr74;
	case 131: goto tr74;
	case 132: goto tr211;
	case 133: goto tr74;
	case 134: goto tr74;
	case 135: goto tr74;
	case 136: goto tr74;
	case 137: goto tr74;
	case 138: goto tr74;
	case 139: goto tr74;
	case 140: goto tr74;
	case 141: goto tr74;
	case 142: goto tr74;
	case 143: goto tr74;
	case 144: goto tr74;
	case 145: goto tr74;
	case 146: goto tr74;
	case 147: goto tr74;
	case 148: goto tr74;
	case 149: goto tr74;
	case 150: goto tr74;
	case 151: goto tr74;
	case 152: goto tr74;
	case 153: goto tr74;
	case 154: goto tr74;
	case 155: goto tr74;
	case 156: goto tr74;
	case 157: goto tr74;
	case 158: goto tr74;
	case 159: goto tr74;
	case 160: goto tr74;
	case 161: goto tr74;
	case 162: goto tr74;
	case 163: goto tr74;
	case 164: goto tr74;
	case 165: goto tr74;
	case 166: goto tr74;
	case 167: goto tr74;
	case 168: goto tr74;
	case 169: goto tr74;
	case 170: goto tr74;
	case 171: goto tr74;
	case 172: goto tr74;
	case 173: goto tr74;
	case 174: goto tr74;
	case 175: goto tr74;
	case 176: goto tr74;
	case 177: goto tr74;
	case 178: goto tr74;
	case 179: goto tr74;
	case 180: goto tr74;
	case 181: goto tr74;
	case 182: goto tr61;
	case 183: goto tr61;
	case 3: goto tr0;
	case 185: goto tr276;
	case 187: goto tr304;
	case 188: goto tr305;
	case 4: goto tr9;
	case 189: goto tr306;
	case 5: goto tr9;
	case 190: goto tr305;
	case 6: goto tr9;
	case 191: goto tr305;
	case 7: goto tr9;
	case 8: goto tr9;
	case 192: goto tr305;
	case 193: goto tr305;
	case 194: goto tr305;
	case 195: goto tr311;
	case 196: goto tr311;
	case 9: goto tr19;
	case 197: goto tr313;
	case 198: goto tr305;
	case 199: goto tr315;
	case 200: goto tr305;
	case 201: goto tr318;
	case 202: goto tr319;
	case 204: goto tr326;
	}
	}

	}

#line 591 "lmscan.rl"

		/* Check if we failed. */
		if ( cs == rlscan_error ) {
			/* Machine failed before finding a token. I'm not yet sure if this
			 * is reachable. */
			scan_error() << "colm scanner error (metalanguage)" << endl;
			exit(1);
		}

		/* Decide if we need to preserve anything. */
		char *preserve = ts;

		/* Now set up the prefix. */
		if ( preserve == 0 )
			have = 0;
		else {
			/* There is data that needs to be shifted over. */
			have = pe - preserve;
			memmove( buf, preserve, have );
			unsigned int shiftback = preserve - buf;
			if ( ts != 0 )
				ts -= shiftback;
			te -= shiftback;

			preserve = buf;
		}
	}
	delete[] buf;
}

void Scanner::eof()
{
	InputLoc loc;
	loc.fileName = "<EOF>";
	loc.line = line;
	loc.col = 1;
	parser->token( loc, Parser_tk_eof, 0, 0 );
}
